# perry-cdom-api-community
![Version](https://img.shields.io/github/v/release/ivancopps/perry-cdom-api-community?include_prereleases)
![PyPi](https://img.shields.io/pypi/v/perry-cdom-api-community?label=latest%20pypi)
![Downloads PyPi](https://img.shields.io/pypi/dm/perry-cdom-api-community)

# Perry Electric CDOM/CRM4.0

**UNOFFICIAL** library for communicating with Perry Electric CDOM/CRM4.0 apis.


# Installation
Use poetry install --extras cli to install dependencies for CLI and the library itself.

# Listing devices
To list all devices, use the list command:

poetry run python3 src/cli.py list
